@@ -1,14 +1,17 @@
-from translate import Translator
-import qrcode
-import string
 import random
 import socket
-import time
-import speedtest  # 测速
+import string
+import subprocess
+from pathlib import Path
+
+import qrcode
+from loguru import logger
+from pofile import mkdir
+from translate import Translator
 
 # from utils.tools.weather_city_code import WEATHER_CITY_CODE_DIC
 from wftools.lib.tools.lottery8ticket import ticket_kinds
-from wftools.lib.tools.pwd4wifi_service import pwd4wifi_service
+# from wftools.lib.tools.pwd4wifi_service import pwd4wifi_service
 from wftools.lib.tools.qoute_dict_create_article import create_article_main
 from wftools.lib.tools.weather_city_code import WEATHER_CITY_CODE_DIC
 from wftools.lib.tools.weather_service import weather_spider
@@ -16,15 +19,15 @@ from wftools.lib.tools.weather_service import weather_spider
 
 class MainTools():
 
-    def transtools(self, to_lang, content):
+    def transtools(self, content, to_lang, from_lang='zh'):
         # specifying the language
-        translator = Translator(to_lang)
+        translator = Translator(to_lang, from_lang)
         # typing the message
         translation = translator.translate(content)
         # print the translated message
-        print(translation)
+        return translation
 
-    def qrcodetools(self, url):
+    def qrcodetools(self, url: str, output: str = r'./qrcode_img.png'):
         # Creating object
         # version: defines size of image from integer(1 to 40), box_size = size of each box in pixels, border = thickness of the border.
         qr = qrcode.QRCode(version=1, box_size=10, border=5)
@@ -34,8 +37,10 @@ class MainTools():
         qr.make(fit=True)
         # specify the foreground and background color for the img
         img = qr.make_image(fill='black', back_color='white')
+        output_abs_path = Path(output).absolute()
+        mkdir(output_abs_path.parent)
         # store the image
-        img.save('qrcode_img.png')
+        img.save(output_abs_path)
 
     def passwordtools(self, len):
         """
@@ -45,7 +50,6 @@ class MainTools():
         """
         chars = string.digits + string.ascii_letters + string.punctuation
         pwd = ''.join(random.sample(chars * len, len))
-        print(pwd)
         return pwd
 
     def weather(self):
@@ -64,10 +68,10 @@ class MainTools():
                 print('未查到%s城市，请重新输入：' % cityName)
 
     # 通过url，获取ip地址
-    def url2ip(self, url):
+    def url2ip(self, url) -> str:
         socket_list = socket.getaddrinfo(url, None, 0, socket.SOCK_STREAM)
         ip_info = socket_list[0][4][0]
-        print('【{}】 这个网址对应的IP地址是：{}'.format(url, ip_info))
+        return str(ip_info)
 
     def lottery8ticket(self):
         '''
@@ -83,7 +87,7 @@ class MainTools():
                 break
             print('*' * 20)
             if not ticket_kinds.get(kind)[1]():
-                print('这个规则太复杂了，我们正在开发。如果可以提供建议，请私信：http://t.cn/A6XVQXAk')
+                print('这个规则太复杂了，我们正在开发。如果可以提供建议，请私信：http://python4office.cn/wechat-qrcode')
             else:
                 print(f'{ticket_kinds.get(kind)[0]}的号码是 -->> {ticket_kinds.get(kind)[1]()}')
             print('*' * 20)
@@ -93,21 +97,15 @@ class MainTools():
 
     # 破解wifi密码
     def pwd4wifi(self, len_pwd, pwd_list):
-        pwd4wifi_service(len_pwd, pwd_list)
+        '该方法已废弃，如有疑问，请联系：http://www.python4office.cn/wechat-group/'
+        # pwd4wifi_service(len_pwd, pwd_list)
 
     def net_speed_test(self):
-        print("准备测试ing...")
-        # 创建实例对象
-        test = speedtest.Speedtest()
-        # 获取可用于测试的服务器列表
-        test.get_servers()
-        # 筛选出最佳服务器
-        best = test.get_best_server()
-        print("正在测试ing...")
-        # 下载速度
-        download_speed = int(test.download() / 1024 / 1024)
-        # 上传速度
-        upload_speed = int(test.upload() / 1024 / 1024)
-        # 输出结果
-        print("下载速度：" + str(download_speed) + " Mbits/s")
-        print("上传速度：" + str(upload_speed) + " Mbits/s")
+        logger.warning('该方法已废弃')
+
+    def open_soft(self, soft_path, num):
+        # 软件路径
+        software_path = Path(soft_path).absolute()
+        # 打开软件
+        for i in range(num):
+            subprocess.Popen(software_path)
